@@ -21,9 +21,9 @@
 
 #include <QApplication>
 #include <QCommandLineParser>
-#include <kaboutdata.h>
-#include <kdelibs4configmigrator.h>
-#include <klocalizedstring.h>
+#include <KAboutData>
+#include <Kdelibs4ConfigMigrator>
+#include <KLocalizedString>
 #include <KDBusService>
 #include <KCrash>
 
@@ -37,6 +37,8 @@ using namespace gui;
 
 int main(int argc, char **argv) {
 
+    // Fixes blurry icons with fractional scaling
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
     Kdelibs4ConfigMigrator migrate(QStringLiteral("bovo"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("bovorc"));
